# Amplitude

Amplitude commands are used to create arbitrary time or frequency variations of load, displacement, and some interaction attributes throughout a step using step time or throughout an analysis using total time.

## Create amplitudes

### In Mdb

```{eval-rst}
.. autoclass:: abaqus.Amplitude.AmplitudeModel.AmplitudeModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

### In Odb

```{eval-rst}
.. autoclass:: abaqus.Amplitude.AmplitudeOdb.AmplitudeOdb
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.Amplitude.Amplitude.Amplitude
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.ActuatorAmplitude.ActuatorAmplitude
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.BaselineCorrection.BaselineCorrection
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.Correlation.Correlation
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.DecayAmplitude.DecayAmplitude
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.EquallySpacedAmplitude.EquallySpacedAmplitude
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.ModulatedAmplitude.ModulatedAmplitude
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.PeriodicAmplitude.PeriodicAmplitude
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.PsdDefinition.PsdDefinition
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.SmoothStepAmplitude.SmoothStepAmplitude
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.SolutionDependentAmplitude.SolutionDependentAmplitude
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.SpectrumAmplitude.SpectrumAmplitude
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Amplitude.TabularAmplitude.TabularAmplitude
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
